@@ -9,6 +9,7 @@
 #' -  `quantile`
 #' -  `probability`
 #' -  `qq`
+#' -  `mcmc`
 #'
 #' @description This is an auto plotting function that will take in a `tidy_`
 #' distribution function and a few arguments, one being the plot type, which is
@@ -17,6 +18,7 @@
 #' -  `quantile`
 #' -  `probablity`
 #' -  `qq`
+#' -  `mcmc`
 #'
 #' If the number of simulations exceeds 9 then the legend will not print. The plot
 #' subtitle is put together by the attributes of the table passed to the function.
@@ -99,7 +101,7 @@ tidy_autoplot <- function(.data, .plot_type = "density", .line_size = .5,
                      greater than 0.")
     }
 
-    if (!plot_type %in% c("density", "quantile", "probability", "qq")) {
+    if (!plot_type %in% c("density", "quantile", "probability", "qq","mcmc")) {
         rlang::abort("You have chose an unsupported plot type.")
     }
 
@@ -279,6 +281,27 @@ tidy_autoplot <- function(.data, .plot_type = "density", .line_size = .5,
                 color = "Simulation"
             ) +
             ggplot2::theme(legend.position = leg_pos)
+    } else if (plot_type == "mcmc") {
+        plt <- data_tbl %>%
+            dplyr::group_by(sim_number) %>%
+            dplyr::mutate(cmy = dplyr::cummean(y)) %>%
+            dplyr::ungroup() %>%
+            ggplot2::ggplot(ggplot2::aes(
+                x = x, y = cmy, group = sim_number, color = sim_number
+            )) +
+            ggplot2::geom_line() +
+            ggplot2::theme_minimal() +
+            ggplot2::scale_x_continuous(trans = "log10") +
+            ggplot2::labs(
+                title = "MCMC Cumulative Mean Plot",
+                caption = "X is on log10 scale.",
+                subtitle = sub_title,
+                color = "Simulation",
+                x = "",
+                y = ""
+            ) +
+            ggplot2::theme(legend.position = leg_pos)
+
     }
 
     if (.geom_rug) {
@@ -291,7 +314,7 @@ tidy_autoplot <- function(.data, .plot_type = "density", .line_size = .5,
             ggplot2::geom_point(size = point_size)
     }
 
-    if (.geom_smooth) {
+    if (.geom_smooth & !plot_type == "mcmc") {
         max_dy <- max(data_tbl$dy)
 
         plt <- plt +
@@ -304,6 +327,16 @@ tidy_autoplot <- function(.data, .plot_type = "density", .line_size = .5,
                 linetype = "dashed"
             ) +
             ggplot2::ylim(0, max_dy)
+    } else if (.geom_smooth & plot_type == "mcmc") {
+        plt <- plt +
+            ggplot2::geom_smooth(
+                ggplot2::aes(
+                    group = FALSE
+                ),
+                se = FALSE,
+                color = "black",
+                linetype = "dashed"
+            )
     }
 
     if (.geom_jitter) {
